@@ -4,7 +4,7 @@ This module defines functions to log requests, and to manage log verbosity.
 """
 import logging
 import json
-from flask import abort, make_response, jsonify, request
+from flask import abort, make_response, jsonify, request as flask_request
 from log_trace.decorators import trace
 from utils import make_error_response
 
@@ -34,7 +34,7 @@ def add_hooks(app):
         if app.auth and not app.auth.authorized(None, '_logging', 'PUT'):
             return make_error_response('Please provide proper credentials', 401)
 
-        return _put_logging_config(request)
+        return _put_logging_config(flask_request)
 
 
 @trace
@@ -48,10 +48,12 @@ def _log_request(resource, request, payload):
 @trace
 def _get_logging_config():
     """Returns the verbosity for all handlers."""
-    payload = {}
+    """Returns the verbosity for all handlers."""
     logger = logging.getLogger()
-    for handler in logger.handlers:
-        payload[handler.name] = logging.getLevelName(handler.level)
+    payload = {
+        handler.name: logging.getLevelName(handler.level)
+        for handler in logger.handlers
+    }
 
     response = make_response(jsonify(payload), 200)
     _log_request('_logging', request, response)
@@ -64,7 +66,7 @@ def _put_logging_config(request):
     response = make_error_response('Could not change log settings', 400)
     
     try:
-        if not request.content_type == 'application/json':
+        if request.content_type != 'application/json':
             raise TypeError('The request body must be application/json')
 
         payload = json.loads(request.data)
